@@ -1,19 +1,8 @@
 /*
- *   Copyright 2009 Marco Martin <notmart@gmail.com>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2009 Marco Martin <notmart@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #ifndef KWINDOWEFFECTS_H
 #define KWINDOWEFFECTS_H
@@ -32,14 +21,16 @@ namespace KWindowEffects
 {
 enum Effect {
     Slide = 1,
-    PresentWindows = 3,
-    PresentWindowsGroup = 4,
-    HighlightWindows = 5,
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 82)
+    PresentWindows KWINDOWSYSTEM_ENUMERATOR_DEPRECATED_VERSION(5, 82, "Check whether org.kde.KWin.PresentWindows d-bus service is registered") = 3,
+    PresentWindowsGroup KWINDOWSYSTEM_ENUMERATOR_DEPRECATED_VERSION(5, 82, "Check whether org.kde.KWin.PresentWindows d-bus service is registered") = 4,
+    HighlightWindows KWINDOWSYSTEM_ENUMERATOR_DEPRECATED_VERSION(5, 82, "Check whether org.kde.KWin.HighlightWindow d-bus service is registered") = 5,
+#endif
     BlurBehind = 7,
 #if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 67)
-    Dashboard = 8,
+    Dashboard KWINDOWSYSTEM_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 67, "Support for dashboard windows in KWin was removed long time ago") = 8,
 #endif
-    BackgroundContrast = 9
+    BackgroundContrast = 9,
 };
 
 enum SlideFromLocation {
@@ -47,7 +38,7 @@ enum SlideFromLocation {
     TopEdge,
     RightEdge,
     BottomEdge,
-    LeftEdge
+    LeftEdge,
 };
 /**
  * @return if an atom property is available
@@ -56,6 +47,7 @@ enum SlideFromLocation {
  */
 KWINDOWSYSTEM_EXPORT bool isEffectAvailable(Effect effect);
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 82)
 /**
  * Mark a window as sliding from screen edge
  *
@@ -63,8 +55,12 @@ KWINDOWSYSTEM_EXPORT bool isEffectAvailable(Effect effect);
  * @param location edge of the screen from which we want the sliding effect.
  *               Desktop and Floating won't have effect.
  * @param offset distance in pixels from the screen edge defined by location
+ *
+ * @deprecated Since 5.82, Use slideWindow(QWindow) overload
  */
+KWINDOWSYSTEM_DEPRECATED_VERSION(5, 82, "Use slideWindow(QWindow) overload")
 KWINDOWSYSTEM_EXPORT void slideWindow(WId id, SlideFromLocation location, int offset = -1);
+#endif
 
 #if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 62)
 /**
@@ -80,39 +76,123 @@ KWINDOWSYSTEM_DEPRECATED_VERSION(5, 62, "Use KWindowEffects::slideWindow(WId, Sl
 KWINDOWSYSTEM_EXPORT void slideWindow(QWidget *widget, SlideFromLocation location);
 #endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 81)
 /**
  * @return dimension of all the windows passed as parameter
  *
  * @param ids all the windows we want the size
+ * @deprecated since 5.81, fetch sizes through KWindowSystem instead
  */
+KWINDOWSYSTEM_DEPRECATED_VERSION(5, 81, "Fetch sizes through KWindowSystem instead")
 KWINDOWSYSTEM_EXPORT QList<QSize> windowSizes(const QList<WId> &ids);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 82)
 /**
-* Activate the Present Windows effect for the given groups of windows.
-*
-* @param controller The window which is the controller of this effect. The property
-*                   will be set on this window. It will be removed by the effect
-* @param ids all the windows which should be presented.
-*/
+ * Activate the Present Windows effect for the given groups of windows.
+ *
+ * @param controller The window which is the controller of this effect. The property
+ *                   will be set on this window. It will be removed by the effect
+ * @param ids all the windows which should be presented.
+ *
+ * @deprecated Since 5.82, Use org.kde.KWin.PresentWindows d-bus api
+ */
+KWINDOWSYSTEM_DEPRECATED_VERSION(5, 82, "Use org.kde.KWin.PresentWindows d-bus api")
 KWINDOWSYSTEM_EXPORT void presentWindows(WId controller, const QList<WId> &ids);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 82)
 /**
  * Activate the Present Windows effect for the windows of the given desktop.
  *
  * @param controller The window which is the controller of this effect. The property
  *                   will be set on this window. It will be removed by the effect
  * @param desktop The desktop whose windows should be presented. -1 for all desktops
+ *
+ * @deprecated Since 5.82, Use org.kde.KWin.PresentWindows d-bus api
  */
+KWINDOWSYSTEM_DEPRECATED_VERSION(5, 82, "Use org.kde.KWin.PresentWindows d-bus api")
 KWINDOWSYSTEM_EXPORT void presentWindows(WId controller, int desktop = NET::OnAllDesktops);
+#endif
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 82)
 /**
  * Highlight the selected windows, making all the others translucent
  *
  * @param controller The window which is the controller of this effect. The property
  *                   will be set on this window. It will be removed by the effect
  * @param ids all the windows which should be highlighted.
+ *
+ * @deprecated Since 5.82, Use org.kde.KWin.HighlightWindow d-bus api
  */
+KWINDOWSYSTEM_DEPRECATED_VERSION(5, 82, "Use org.kde.KWin.HighlightWindow d-bus api")
 KWINDOWSYSTEM_EXPORT void highlightWindows(WId controller, const QList<WId> &ids);
+#endif
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 82)
+/**
+ * Instructs the window manager to blur the background
+ * in the specified region behind the given window.
+ * The given region will overwrite any previous blur-behind region.
+ * Passing a null region will enable the blur effect for the whole window.
+ * The region is relative to the top-left corner of the client area.
+ *
+ * If @a enable is @c false, blur will be disabled for the whole window
+ * (@a region is ignored).
+ *
+ * Note that you will usually want to set the region to the shape of the window,
+ * excluding any shadow or halo.
+ *
+ * @param window The window for which to enable the blur effect
+ * @param enable Enable the effect if @c true, disable it if @c false
+ * @param region The region within the window where the background will be blurred, specified in logical pixels
+ *
+ * @deprecated Since 5.82, use enableBlurBehind(QWindow) overload.
+ */
+KWINDOWSYSTEM_DEPRECATED_VERSION(5, 82, "Use enableBlurBehind(QWindow) overload")
+KWINDOWSYSTEM_EXPORT void enableBlurBehind(WId window, bool enable = true, const QRegion &region = QRegion());
+#endif
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 82)
+/**
+ * Instructs the window manager to modify the color of the background
+ * in the specified region behind the given window,
+ * in order to improve the contrast and readability of any text
+ * in the translucent window.
+ * The given region will overwrite any previous backgroundcontrast region.
+ * Passing a null region will enable the blur effect for the whole window.
+ * The region is relative to the top-left corner of the client area.
+ *
+ * If @a enable is @c false, blur will be disabled for the whole window
+ * (@a region is ignored).
+ *
+ * Note that you will usually want to set the region to the shape of the window,
+ * excluding any shadow or halo.
+ *
+ * @param window The window for which to enable the background contrast effect
+ * @param enable Enable the effect if @c true, disable it if @c false
+ * @param brightness How to modify the area brightness: from 0 (make it black) to 2 (make it white), 1 leaves it unchanged
+ * @param region The region within the window where the background will be modified, specified in logical pixels
+ *
+ * @deprecated Since 5.82, use enableBackgroundContrast(QWindow) overload.
+ */
+KWINDOWSYSTEM_DEPRECATED_VERSION(5, 82, "Use enableBackgroundContrast(QWindow) overload")
+KWINDOWSYSTEM_EXPORT void
+enableBackgroundContrast(WId window, bool enable = true, qreal contrast = 1, qreal intensity = 1, qreal saturation = 1, const QRegion &region = QRegion());
+#endif
+
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 67)
+/**
+ * Instructs the window manager to handle the given window as dashboard window as
+ * Dashboard windows should be handled diffrently and may have special effects
+ * applied to them.
+ *
+ * @param window The window for which to enable the blur effect
+ * @deprecated since 5.67, support for dashboard windows was removed
+ */
+KWINDOWSYSTEM_DEPRECATED_VERSION(5, 67, "Support for dashboard windows was removed")
+KWINDOWSYSTEM_EXPORT void markAsDashboard(WId window);
+#endif
 
 /**
  * Instructs the window manager to blur the background
@@ -130,8 +210,10 @@ KWINDOWSYSTEM_EXPORT void highlightWindows(WId controller, const QList<WId> &ids
  * @param window The window for which to enable the blur effect
  * @param enable Enable the effect if @c true, disable it if @c false
  * @param region The region within the window where the background will be blurred, specified in logical pixels
+ *
+ * @since 5.82
  */
-KWINDOWSYSTEM_EXPORT void enableBlurBehind(WId window, bool enable = true, const QRegion &region = QRegion());
+KWINDOWSYSTEM_EXPORT void enableBlurBehind(QWindow *window, bool enable = true, const QRegion &region = QRegion());
 
 /**
  * Instructs the window manager to modify the color of the background
@@ -152,22 +234,23 @@ KWINDOWSYSTEM_EXPORT void enableBlurBehind(WId window, bool enable = true, const
  * @param enable Enable the effect if @c true, disable it if @c false
  * @param brightness How to modify the area brightness: from 0 (make it black) to 2 (make it white), 1 leaves it unchanged
  * @param region The region within the window where the background will be modified, specified in logical pixels
- */
-KWINDOWSYSTEM_EXPORT void enableBackgroundContrast(WId window, bool enable = true, qreal contrast = 1, qreal intensity = 1, qreal saturation = 1, const QRegion &region = QRegion());
-
-#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 67)
-/**
- * Instructs the window manager to handle the given window as dashboard window as
- * Dashboard windows should be handled diffrently and may have special effects
- * applied to them.
  *
- * @param window The window for which to enable the blur effect
- * @deprecated since 5.67, support for dashboard windows was removed
+ * @since 5.82
  */
-KWINDOWSYSTEM_DEPRECATED_VERSION(5, 67, "Support for dashboard windows was removed")
-KWINDOWSYSTEM_EXPORT void markAsDashboard(WId window);
-#endif
+KWINDOWSYSTEM_EXPORT void
+enableBackgroundContrast(QWindow *window, bool enable = true, qreal contrast = 1, qreal intensity = 1, qreal saturation = 1, const QRegion &region = QRegion());
+
+/**
+ * Mark a window as sliding from screen edge
+ *
+ * @param id of the window on which we want to apply the effect
+ * @param location edge of the screen from which we want the sliding effect.
+ *               Desktop and Floating won't have effect.
+ * @param offset distance in pixels from the screen edge defined by location
+ *
+ * @since 5.82
+ */
+KWINDOWSYSTEM_EXPORT void slideWindow(QWindow *window, SlideFromLocation location, int offset = -1);
 }
 
 #endif
-
